@@ -1,3 +1,7 @@
+( cd opt/kde/share/doc/HTML/uk/khelpcenter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/uk/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/uk/common common )
+( cd opt/kde/share/doc/HTML/uk/kioslave ; rm -rf common )
+( cd opt/kde/share/doc/HTML/uk/kioslave ; ln -sf /opt/kde/share/doc/HTML/uk/common common )
 ( cd opt/kde/share/doc/HTML/uk/kaddressbook ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/uk/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/uk/common common )
 ( cd opt/kde/share/doc/HTML/uk/common ; rm -rf fdl-license )
@@ -26,16 +30,28 @@
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/8.png 8.png )
 ( cd opt/kde/share/doc/HTML/uk/common ; rm -rf 9.png )
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/9.png 9.png )
+( cd opt/kde/share/doc/HTML/uk/common ; rm -rf headerbg.png )
+( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
 ( cd opt/kde/share/doc/HTML/uk/common ; rm -rf gpl-license.html )
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
+( cd opt/kde/share/doc/HTML/uk/common ; rm -rf mainheader.html )
+( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
+( cd opt/kde/share/doc/HTML/uk/common ; rm -rf grad.png )
+( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/grad.png grad.png )
 ( cd opt/kde/share/doc/HTML/uk/common ; rm -rf kde-web.css )
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
 ( cd opt/kde/share/doc/HTML/uk/common ; rm -rf lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
+( cd opt/kde/share/doc/HTML/uk/common ; rm -rf doxygen.css )
+( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
 ( cd opt/kde/share/doc/HTML/uk/common ; rm -rf web-doctop.png )
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
 ( cd opt/kde/share/doc/HTML/uk/common ; rm -rf kde-default.css )
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
+( cd opt/kde/share/doc/HTML/uk/common ; rm -rf kmenu.png )
+( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
+( cd opt/kde/share/doc/HTML/uk/common ; rm -rf footer.html )
+( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/uk/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
 ( cd opt/kde/share/doc/HTML/uk/common ; rm -rf doctop1.png )
@@ -44,6 +60,8 @@
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
 ( cd opt/kde/share/doc/HTML/uk/common ; rm -rf shadow.png )
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/shadow.png shadow.png )
+( cd opt/kde/share/doc/HTML/uk/common ; rm -rf docheadergears.png )
+( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
 ( cd opt/kde/share/doc/HTML/uk/common ; rm -rf fdl-license.html )
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
 ( cd opt/kde/share/doc/HTML/uk/common ; rm -rf doctop1a.png )
@@ -54,10 +72,14 @@
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
 ( cd opt/kde/share/doc/HTML/uk/common ; rm -rf lgpl-license )
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
+( cd opt/kde/share/doc/HTML/uk/common ; rm -rf mainfooter.html )
+( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
 ( cd opt/kde/share/doc/HTML/uk/common ; rm -rf bottom1.png )
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/bottom1.png bottom1.png )
 ( cd opt/kde/share/doc/HTML/uk/common ; rm -rf bottom2.png )
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
+( cd opt/kde/share/doc/HTML/uk/common ; rm -rf header.html )
+( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/header.html header.html )
 ( cd opt/kde/share/doc/HTML/uk/common ; rm -rf gpl-license )
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/gpl-license gpl-license )
 ( cd opt/kde/share/doc/HTML/uk/common ; rm -rf kde-localised.css.template )
@@ -70,3 +92,5 @@
 ( cd opt/kde/share/doc/HTML/uk/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
 ( cd opt/kde/share/doc/HTML/uk/kspell ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/uk/kspell ; ln -sf /opt/kde/share/doc/HTML/uk/common common )
+( cd opt/kde/share/doc/HTML/uk/kinfocenter/protocols ; rm -rf common )
+( cd opt/kde/share/doc/HTML/uk/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/uk/common common )
